www.focalprice.com helpindex

- Home

- Help
- My Account
- Order Tracking
- Sign in or Register
- Welcome! MixSun Sign out

Wellcome to Focalprice!

#### Policy

- Product Warranty
- Return Policy
- Term of Use
- Privacy & Security Policy

#### FAQs

- Payment
- Shipping
- Returns (RMA)
- Points,Coupons&Gifts
- Products Warranty
- Ordering
- My Account

#### Contact Us

- My Message& RMA
- Telephone
- Live Chat

#### Business Opportunities

- Advantage
- Wholesale
- Affiliate Program

#### Partner Links

#### About Us

#### Links

#### Tags

#### Legal window

#

- My Message & RMA

# My Message & RMA

My Message:

For routine inquiries or requests, such as new products, shipping information, Focal Points account, or order change/cancellation, kindly contact us via "My Message". Please follow these steps: Log in to "My Account" on www.focalprice.com → "My message" → "Submit a ticket" → "Submit"

RMA:

For missing/wrong product shipments or damage issues, you can submit an RMA request via our website. Please follow these steps: Log in to "My Account" on www.focalprice.com→”RMA Request”→”Submit”

© 2008-2011 FocalPrice.com. All rights reserved.